app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("testWrongInputEvaluatePoints")

app$setInputs(objectiveFunction = "rEnv")
app$setInputs(funName = "fakeFunctionForTesting")
app$setInputs(addDimension = "click")
app$setInputs(dimensionAmount2 = 2)
app$setInputs(tabs = "spotConfig")
app$setInputs(tabs = "runMode")
app$setInputs(runCreateDOE = "click")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(funName = "funBranin")
app$setInputs(tabs = "spotConfig")
app$setInputs(tabs = "runMode")
app$setInputs(runCreateDOE = "click")
app$setInputs(tabs = "objectiveFunction")
app$setInputs(funName = "fakeFunctionForTesting")
app$setInputs(tabs = "runMode")
app$setInputs(evaluateData = "click")
Sys.sleep(2)
app$snapshot(list(output = "resultTable"))
